#error "/home/espenr/tmp/qt-3-espenr-26122/qt/extensions/nsplugin/src/jri.h must be provided by Netscape"
#error "This file is just a placeholder. Please see the documentation"
#error "to learn how to obtain the real file"
